@@ -17,7 +17,7 @@ pub fn de_pad(input: &mut Vec<u8>) {
 }
 
 #[inline(always)]
-pub fn to_blocks(input: Vec<u8>) -> Vec<ZestBlock> {
+fn to_blocks(input: Vec<u8>) -> Vec<ZestBlock> {
     let mut blocks: Vec<ZestBlock> = vec![];
     for block in input.array_chunks::<512>() {
         blocks.push((*block).into());
