@@ -29,7 +29,7 @@ impl ZestRand {
         let mut initial = ZestRand {
             seed: seed.unwrap_or_default(),
             hash_output: ZestBlock::default(),
-            byte_offset: 0
+            byte_offset: 0,
         };
         initial.hash_output = zest4096(initial.seed);
         initial
